pub fn assert_has_pattern(
instructions: &[Instruction],
pattern: &[InstructionPattern],
)Expand description
Assert that an instruction sequence contains a pattern
Panics with a descriptive message if the pattern is not found
pub fn assert_has_pattern(
instructions: &[Instruction],
pattern: &[InstructionPattern],
)Assert that an instruction sequence contains a pattern
Panics with a descriptive message if the pattern is not found